[Xfce4-commits] [xfce/thunar] 03/03: Also query for network location icons.

noreply at xfce.org noreply at xfce.org
Sat Feb 28 12:27:37 CET 2015


This is an automated email from the git hooks/post-receive script.

nick pushed a commit to branch master
in repository xfce/thunar.

commit a8d7ab641e06aeb0ae693c9ee4cb17bcaec5c7df
Author: Nick Schermer <nick at xfce.org>
Date:   Sat Feb 28 12:27:21 2015 +0100

    Also query for network location icons.
---
 thunar/thunar-file.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/thunar/thunar-file.c b/thunar/thunar-file.c
index 244b658..2511fc8 100644
--- a/thunar/thunar-file.c
+++ b/thunar/thunar-file.c
@@ -3592,7 +3592,7 @@ thunar_file_get_icon_name_for_state (const gchar         *icon_name,
 const gchar *
 thunar_file_get_icon_name (ThunarFile          *file,
                            ThunarFileIconState  icon_state,
-                           GtkIconTheme       *icon_theme)
+                           GtkIconTheme        *icon_theme)
 {
   GFile               *icon_file;
   GIcon               *icon = NULL;
@@ -3663,9 +3663,10 @@ thunar_file_get_icon_name (ThunarFile          *file,
           goto check_names;
         }
     }
-  else if (thunar_file_is_mountable (file))
+  else if (thunar_file_is_mountable (file)
+           || g_file_has_uri_scheme (file->gfile, "network"))
     {
       /* query the icon (computer:// backend) */
       fileinfo = g_file_query_info (file->gfile,
                                     G_FILE_ATTRIBUTE_STANDARD_ICON,
                                     G_FILE_QUERY_INFO_NONE, NULL, NULL);
@@ -3693,7 +3694,6 @@ thunar_file_get_icon_name (ThunarFile          *file,
   if (G_LIKELY (icon != NULL))
     {
       check_icon:
-
       if (G_IS_THEMED_ICON (icon))
         {
           names = g_themed_icon_get_names (G_THEMED_ICON (icon));
@@ -3663,9 +3663,10 @@ thunar_file_get_icon_name (ThunarFile          *file,
     {
-      /* query the icon (computer:// backend) */
+      /* query the icon (computer:// and network:// backend) */
       fileinfo = g_file_query_info (file->gfile,
                                     G_FILE_ATTRIBUTE_STANDARD_ICON,

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list